import axios from "axios";
import { getToken } from "./token";
const baseURL = "https://lygsh-api.wjzpgz.com/";
// const baseURL = "http://192.168.11.82:8080/";
// 创建一个 axios 实例
const instance = axios.create({
    baseURL, // 设置基础 URL
    // baseURL: "http://192.168.11.63:8080/", // 设置基础 URL
    timeout: 5000, // 设置请求超时时间
    headers: {
        "Content-Type": "application/json" // 设置默认请求头
    }
});

// 请求拦截器
instance.interceptors.request.use(
    config => {
        // 在这里可以添加请求发送前的处理逻辑，例如添加 token 等
        // const token = localStorage.getItem('token');
        // if (token) {
        //   config.headers.Authorization = `Bearer ${token}`;
        // }·
        const token = getToken();
        config.headers["User-Token"] = token;
        uni.showLoading({
            title: "加载中..."
        })
        return config;
    },
    error => {
        // 处理请求错误
        return Promise.reject(error);
    }
);

// 响应拦截器
instance.interceptors.response.use(
    response => {
        let { code, message,data } = response.data;
        if (code === 4 || code === 8) {
            uni.showToast({
                title: message,
                icon: "none"
            });
        }
        if (code === 9) {
            const path = getCurrentPages()[0].$page.path
            if(path === '/pages/user/resume/essentialInformation/index') return
            uni.showModal({
                title: "提示",
                content: "请先完善基本信息！",
                success: function (res) {
                    if (res.confirm) {
                        uni.navigateTo({
                            url: "/pages/user/resume/essentialInformation/index"
                        });
                    } else if (res.cancel) {
                        console.log("用户点击取消");
                    }
                }
            });
        } else if (code === 13) {
            if (data > 0) {
                uni.showModal({
                    title: '您的申诉已提交',
                    content: '请等待审核，无需重复提交',
                    success: function (confirm) {
                        if (confirm.confirm) {
                            xma.reLaunch({
                                url: '/pages/login/index'
                            })
                        }
    
                    }
                })
            } else {
                uni.showModal({
                    title: '您的帐号已失效',
                    content: '由于您超过1月未登录现已将您的账号禁用您可完成申述后继续使用',
                    showCancel: true,
                    confirmText: '立即申述',
                    success: function (confirm) {
                        if (confirm.confirm) {
                            xma.navigateTo({
                                url: '/pages/postionList/appeal/index'
                            })
                        }
    
                    }
                }); 
            }
        } else if (code === 14) {
            uni.showModal({
                title: '提示',
                content: '您的账号已被禁用',
                success: function (confirm) {
                    if (confirm.confirm) {
                        // console.log('已禁用');
                    }

                }
            })
        }
        uni.hideLoading()
        // 在这里可以对响应数据进行预处理
        return response.data;
    },
    error => {
        // 处理响应错误
        // 例如根据不同的错误状态码进行相应的处理
        return Promise.reject(error);
    }
);

export default instance;
